@@ -8,11 +8,11 @@
 using namespace Solid::Backends::Fake;
 
 FakeDeviceInterface::FakeDeviceInterface(FakeDevice *device)
-    : QObject(device), m_device(device)
+    : QObject(device)
+    , m_device(device)
 {
 }
 
 FakeDeviceInterface::~FakeDeviceInterface()
 {
 }
-
